#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 loop
version:              0.3.0
visibility:           public
id:                   loop-0.3.0-H8rzPv1HPWqBamYYXv1mMj
key:                  loop-0.3.0-H8rzPv1HPWqBamYYXv1mMj
license:              MIT
copyright:            2014 Niklas Hambüchen <mail@nh2.me>
maintainer:           Niklas Hambüchen <mail@nh2.me>
author:               Niklas Hambüchen <mail@nh2.me>
stability:            experimental
homepage:             https://github.com/nh2/loop
synopsis:             Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.

    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.

category:             Control
abi:                  d8840ab6432f510c5f15dcac1b654901
exposed:              True
exposed-modules:      Control.Loop Control.Loop.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/loop-0.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/loop-0.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-loop
hs-libraries:         HSloop-0.3.0-H8rzPv1HPWqBamYYXv1mMj
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html:         /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

